SessionConfig

Struct SessionConfig 

pub struct SessionConfig {
    pub expires_in: Duration,
    pub update_age: Option<Duration>,
    pub disable_session_refresh: bool,
    pub fresh_age: Option<Duration>,
    pub cookie_name: String,
    pub cookie_secure: bool,
    pub cookie_http_only: bool,
    pub cookie_same_site: SameSite,
    pub cookie_cache: Option<CookieCacheConfig>,
}
Session-specific configuration

Fields

expires_in: Duration

Session expiration duration

update_age: Option<Duration>

How often to refresh the session expiry (as a Duration).

When set, session expiry is only updated if the session is older than this duration since the last update. When None, every request refreshes the session (equivalent to the old update_age: true).

disable_session_refresh: bool

If true, sessions are never automatically refreshed on access.

fresh_age: Option<Duration>

Session freshness window. A session younger than this is considered “fresh” (useful for step-up auth or sensitive operations).

cookie_name: String

Cookie name for session token

cookie_secure: bool

Cookie settings

cookie_http_only: boolcookie_same_site: SameSitecookie_cache: Option<CookieCacheConfig>

Optional cookie-based session cache to avoid DB lookups.

When enabled, session data is cached in a signed/encrypted cookie. SessionManager checks the cookie cache before hitting the database.